==> eam-wshub-proxyclient-11.4-8-sources.jar: net/datastream/schemas/mp_fields/CHANGENOTICELOCATIONID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour CHANGENOTICELOCATIONID_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="CHANGENOTICELOCATIONID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CHANGENOTICEID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}LOCATIONID"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "CHANGENOTICELOCATIONID_Type", propOrder = {
    "changenoticeid",
    "locationid"
})
public class CHANGENOTICELOCATIONID_Type {

    @XmlElement(name = "CHANGENOTICEID", required = true)
    protected CHANGENOTICEID_Type changenoticeid;
    @XmlElement(name = "LOCATIONID", required = true)
    protected LOCATIONID_Type locationid;

    /**
     * Obtient la valeur de la propriété changenoticeid.
     * 
     * @return
     *     possible object is
     *     {@link CHANGENOTICEID_Type }
     *     
     */
    public CHANGENOTICEID_Type getCHANGENOTICEID() {
        return changenoticeid;
    }

    /**
     * Définit la valeur de la propriété changenoticeid.
     * 
     * @param value
     *     allowed object is
     *     {@link CHANGENOTICEID_Type }
     *     
     */
    public void setCHANGENOTICEID(CHANGENOTICEID_Type value) {
        this.changenoticeid = value;
    }

    /**
     * Obtient la valeur de la propriété locationid.
     * 
     * @return
     *     possible object is
     *     {@link LOCATIONID_Type }
     *     
     */
    public LOCATIONID_Type getLOCATIONID() {
        return locationid;
    }

    /**
     * Définit la valeur de la propriété locationid.
     * 
     * @param value
     *     allowed object is
     *     {@link LOCATIONID_Type }
     *     
     */
    public void setLOCATIONID(LOCATIONID_Type value) {
        this.locationid = value;
    }

}

==> eam-wshub-proxyclient-12.0-sources.jar: net/datastream/schemas/mp_fields/CHANGENOTICELOCATIONID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for CHANGENOTICELOCATIONID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="CHANGENOTICELOCATIONID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CHANGENOTICEID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}LOCATIONID"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "CHANGENOTICELOCATIONID_Type", propOrder = {
    "changenoticeid",
    "locationid"
})
public class CHANGENOTICELOCATIONID_Type {

    @XmlElement(name = "CHANGENOTICEID", required = true)
    protected CHANGENOTICEID_Type changenoticeid;
    @XmlElement(name = "LOCATIONID", required = true)
    protected LOCATIONID_Type locationid;

    /**
     * Gets the value of the changenoticeid property.
     * 
     * @return
     *     possible object is
     *     {@link CHANGENOTICEID_Type }
     *     
     */
    public CHANGENOTICEID_Type getCHANGENOTICEID() {
        return changenoticeid;
    }

    /**
     * Sets the value of the changenoticeid property.
     * 
     * @param value
     *     allowed object is
     *     {@link CHANGENOTICEID_Type }
     *     
     */
    public void setCHANGENOTICEID(CHANGENOTICEID_Type value) {
        this.changenoticeid = value;
    }

    /**
     * Gets the value of the locationid property.
     * 
     * @return
     *     possible object is
     *     {@link LOCATIONID_Type }
     *     
     */
    public LOCATIONID_Type getLOCATIONID() {
        return locationid;
    }

    /**
     * Sets the value of the locationid property.
     * 
     * @param value
     *     allowed object is
     *     {@link LOCATIONID_Type }
     *     
     */
    public void setLOCATIONID(LOCATIONID_Type value) {
        this.locationid = value;
    }

}
